@@ -1,3 +1,5 @@
+import datetime
+import json
 import uuid
 
 from bson import ObjectId
@@ -5,6 +7,22 @@ from bson import ObjectId
 from mobio.libs.dynamic_field.models.mongo.db_manager import DBManager
 
 
+class JSONEncoder(json.JSONEncoder):
+    def default(self, o):
+        if isinstance(o, ObjectId):
+            return str(o)
+        elif type(o) == datetime.date:
+            a = datetime.datetime.combine(o, datetime.datetime.min.time())
+            return a.strftime("%Y-%m-%dT%H:%M:%S.000Z")
+        elif type(o) == datetime.datetime:
+            return o.strftime("%Y-%m-%dT%H:%M:%S.%fZ")
+        elif isinstance(o, uuid.UUID):
+            return str(o)
+        elif isinstance(o, (bytes, bytearray)):
+            return str(o, "utf-8")
+        return json.JSONEncoder.default(self, o)
+
+
 class BaseModel(object):
     CREATED_TIME = "created_time"
     UPDATED_TIME = "updated_time"
